@@ -27,6 +27,21 @@ from magnum.common import policy
 from magnum import objects
 
 
+class ClusterID(wtypes.Base):
+    """API representation of a cluster ID
+
+    This class enforces type checking and value constraints, and converts
+    between the internal object model and the API representation of a cluster
+    ID.
+    """
+
+    uuid = types.uuid
+    """Unique UUID for this cluster"""
+
+    def __init__(self, uuid):
+        self.uuid = uuid
+
+
 class Certificate(base.APIBase):
     """API representation of a certificate.
 
@@ -73,6 +88,9 @@ class Certificate(base.APIBase):
     pem = wtypes.StringType()
     """"The Signed Certificate"""
 
+    ca_cert_type = wtypes.StringType()
+    """"The CA Certificate type the CSR will be signed by"""
+
     def __init__(self, **kwargs):
         super(Certificate, self).__init__()
 
@@ -98,7 +116,7 @@ class Certificate(base.APIBase):
     def _convert_with_links(certificate, url, expand=True):
         if not expand:
             certificate.unset_fields_except(['bay_uuid', 'cluster_uuid',
-                                             'csr', 'pem'])
+                                             'csr', 'pem', 'ca_cert_type'])
 
         certificate.links = [link.Link.make_link('self', url,
                                                  'certificates',
@@ -120,7 +138,8 @@ class Certificate(base.APIBase):
         sample = cls(bay_uuid='7ae81bb3-dec3-4289-8d6c-da80bd8001ae',
                      cluster_uuid='7ae81bb3-dec3-4289-8d6c-da80bd8001ae',
                      created_at=timeutils.utcnow(),
-                     csr='AAA....AAA')
+                     csr='AAA....AAA',
+                     ca_cert_type='kubernetes')
         return cls._convert_with_links(sample, 'http://localhost:9511', expand)
 
 
@@ -134,8 +153,8 @@ class CertificateController(base.Controller):
         'detail': ['GET'],
     }
 
-    @expose.expose(Certificate, types.uuid_or_name)
-    def get_one(self, cluster_ident):
+    @expose.expose(Certificate, types.uuid_or_name, wtypes.text)
+    def get_one(self, cluster_ident, ca_cert_type=None):
         """Retrieve CA information about the given cluster.
 
         :param cluster_ident: UUID of a cluster or
@@ -143,9 +162,10 @@ class CertificateController(base.Controller):
         """
         context = pecan.request.context
         cluster = api_utils.get_resource('Cluster', cluster_ident)
-        policy.enforce(context, 'certificate:get', cluster,
+        policy.enforce(context, 'certificate:get', cluster.as_dict(),
                        action='certificate:get')
-        certificate = pecan.request.rpcapi.get_ca_certificate(cluster)
+        certificate = pecan.request.rpcapi.get_ca_certificate(cluster,
+                                                              ca_cert_type)
         return Certificate.convert_with_links(certificate)
 
     @expose.expose(Certificate, body=Certificate, status_code=201)
@@ -156,7 +176,7 @@ class CertificateController(base.Controller):
         """
         context = pecan.request.context
         cluster = certificate.get_cluster()
-        policy.enforce(context, 'certificate:create', cluster,
+        policy.enforce(context, 'certificate:create', cluster.as_dict(),
                        action='certificate:create')
         certificate_dict = certificate.as_dict()
         certificate_dict['project_id'] = context.project_id
@@ -167,13 +187,16 @@ class CertificateController(base.Controller):
                                                          cert_obj)
         return Certificate.convert_with_links(new_cert)
 
-    @expose.expose(None, types.uuid_or_name, status_code=202)
+    @expose.expose(ClusterID, types.uuid_or_name, status_code=202)
     def patch(self, cluster_ident):
         context = pecan.request.context
         cluster = api_utils.get_resource('Cluster', cluster_ident)
-        policy.enforce(context, 'certificate:rotate_ca', cluster,
+        policy.enforce(context, 'certificate:rotate_ca', cluster.as_dict(),
                        action='certificate:rotate_ca')
         if cluster.cluster_template.tls_disabled:
             raise exception.NotSupported("Rotating the CA certificate on a "
                                          "non-TLS cluster is not supported")
+
         pecan.request.rpcapi.rotate_ca_certificate(cluster)
+
+        return ClusterID(cluster.uuid)
