@@ -98,6 +98,7 @@ class MagnumBase(models.TimestampMixin,
 
         super(MagnumBase, self).save(session)
 
+
 Base = declarative_base(cls=MagnumBase)
 
 
@@ -144,9 +145,12 @@ class Cluster(Base):
     # so, we use 512 chars to get some buffer.
     ca_cert_ref = Column(String(512, mysql_ndb_type=mysql_TEXT))
     magnum_cert_ref = Column(String(512, mysql_ndb_type=mysql_TEXT))
+    etcd_ca_cert_ref = Column(String(512, mysql_ndb_type=mysql_TEXT))
+    front_proxy_ca_cert_ref = Column(String(512, mysql_ndb_type=mysql_TEXT))
     fixed_network = Column(String(255, mysql_ndb_type=TINYTEXT))
     fixed_subnet = Column(String(255, mysql_ndb_type=TINYTEXT))
     floating_ip_enabled = Column(Boolean, default=True)
+    master_lb_enabled = Column(Boolean, default=False)
 
 
 class ClusterTemplate(Base):
@@ -189,6 +193,7 @@ class ClusterTemplate(Base):
     master_lb_enabled = Column(Boolean, default=False)
     floating_ip_enabled = Column(Boolean, default=True)
     hidden = Column(Boolean, default=False)
+    tags = Column(String(255))
 
 
 class X509KeyPair(Base):
@@ -289,3 +294,7 @@ class NodeGroup(Base):
     max_node_count = Column(Integer())
     min_node_count = Column(Integer())
     is_default = Column(Boolean, default=False)
+    stack_id = Column(String(255))
+    status = Column(String(20))
+    status_reason = Column(Text)
+    version = Column(String(20))
