@@ -10,8 +10,9 @@
 #    See the License for the specific language governing permissions and
 #    limitations under the License.
 
+from unittest import mock
+
 import fixtures
-import mock
 from oslo_config import cfg
 from webob import exc as webob_exc
 
@@ -40,7 +41,7 @@ class TestRootController(api_base.FunctionalTest):
                                [{u'href': u'http://localhost/v1/',
                                  u'rel': u'self'}],
                            u'status': u'CURRENT',
-                           u'max_version': u'1.9',
+                           u'max_version': u'1.10',
                            u'min_version': u'1.1'}]}
 
         self.v1_expected = {
