@@ -11,8 +11,8 @@
 #    limitations under the License.
 
 import datetime
+from unittest import mock
 
-import mock
 from oslo_config import cfg
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
@@ -246,9 +246,9 @@ class TestListCluster(api_base.FunctionalTest):
         self.assertIn('links', response.keys())
         self.assertEqual(2, len(response['links']))
         self.assertIn(uuid, response['links'][0]['href'])
-        for l in response['links']:
-            bookmark = l['rel'] == 'bookmark'
-            self.assertTrue(self.validate_link(l['href'],
+        for link in response['links']:
+            bookmark = link['rel'] == 'bookmark'
+            self.assertTrue(self.validate_link(link['href'],
                                                bookmark=bookmark))
 
     def test_collection_links(self):
@@ -511,6 +511,30 @@ class TestPatch(api_base.FunctionalTest):
             self.cluster_obj.health_status_reason, False)
         self.assertEqual(202, response.status_code)
 
+    def test_update_cluster_with_zero_node_count_fail(self):
+        node_count = 0
+        response = self.patch_json(
+            '/clusters/%s' % self.cluster_obj.uuid,
+            [{'path': '/node_count', 'value': node_count,
+              'op': 'replace'}],
+            headers={'OpenStack-API-Version': 'container-infra 1.9'},
+            expect_errors=True)
+
+        self.assertEqual(400, response.status_code)
+
+    def test_update_cluster_with_zero_node_count(self):
+        node_count = 0
+        response = self.patch_json(
+            '/clusters/%s' % self.cluster_obj.uuid,
+            [{'path': '/node_count', 'value': node_count,
+              'op': 'replace'}],
+            headers={'OpenStack-API-Version': 'container-infra 1.10'})
+
+        self.mock_cluster_update.assert_called_once_with(
+            mock.ANY, node_count, self.cluster_obj.health_status,
+            self.cluster_obj.health_status_reason, False)
+        self.assertEqual(202, response.status_code)
+
     def test_remove_ok(self):
         response = self.get_json('/clusters/%s' % self.cluster_obj.uuid)
         self.assertIsNotNone(response['name'])
@@ -678,13 +702,23 @@ class TestPost(api_base.FunctionalTest):
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(202, response.status_int)
 
-    def test_create_cluster_with_node_count_zero(self):
+    def test_create_cluster_with_zero_node_count_fail(self):
         bdict = apiutils.cluster_post_data()
         bdict['node_count'] = 0
-        response = self.post_json('/clusters', bdict, expect_errors=True)
+        response = self.post_json('/clusters', bdict, expect_errors=True,
+                                  headers={"Openstack-Api-Version":
+                                           "container-infra 1.9"})
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(400, response.status_int)
-        self.assertTrue(response.json['errors'])
+
+    def test_create_cluster_with_zero_node_count(self):
+        bdict = apiutils.cluster_post_data()
+        bdict['node_count'] = 0
+        response = self.post_json('/clusters', bdict,
+                                  headers={"Openstack-Api-Version":
+                                           "container-infra 1.10"})
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(202, response.status_int)
 
     def test_create_cluster_with_node_count_negative(self):
         bdict = apiutils.cluster_post_data()
@@ -697,7 +731,7 @@ class TestPost(api_base.FunctionalTest):
     def test_create_cluster_with_no_node_count(self):
         bdict = apiutils.cluster_post_data()
         del bdict['node_count']
-        response = self.post_json('/clusters', bdict, expect_errors=True)
+        response = self.post_json('/clusters', bdict)
         self.assertEqual('application/json', response.content_type)
         self.assertEqual(202, response.status_int)
 
@@ -970,6 +1004,17 @@ class TestPost(api_base.FunctionalTest):
         # Verify flavor_id from ClusterTemplate is used
         self.assertEqual('m1.small', cluster[0].flavor_id)
 
+    def test_create_cluster_with_cinder_csi_disabled(self):
+        self.cluster_template.volume_driver = 'cinder'
+        self.cluster_template.save()
+        cluster_labels = {'cinder_csi_enabled': 'false'}
+        bdict = apiutils.cluster_post_data(labels=cluster_labels)
+        note = 'in-tree Cinder volume driver is deprecated'
+        with self.assertWarnsRegex(DeprecationWarning, note):
+            response = self.post_json('/clusters', bdict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(202, response.status_int)
+
     def test_create_cluster_without_merge_labels(self):
         self.cluster_template.labels = {'label1': 'value1', 'label2': 'value2'}
         self.cluster_template.save()
